### R code from vignette source 'iapws.Rnw'

###################################################
### code chunk number 1: iapws.Rnw:35-36 (eval = FALSE)
###################################################
## install.packages("iapws")


###################################################
### code chunk number 2: iapws.Rnw:43-44
###################################################
library(iapws)


###################################################
### code chunk number 3: iapws.Rnw:49-50
###################################################
iapws95(c("p", "h"), rho = 800, t = seq(573, 623, by = 10))


###################################################
### code chunk number 4: iapws.Rnw:64-66
###################################################
iapws95_pt(c("rho", "h"), p = 0.1013125,  # atmospheric pressure
	   t = seq(293, 373, by = 20))


